Welcome to exSpy's documentation!
***********************************
**exSpy** is a Python package extending the functionality for multi-dimensional
data analysis provided by the `HyperSpy <https://hyperspy.org/>`_ library. It is
aimed at helping with the analysis of X-rays Energy Dispersive Spectroscopy (EDS)
and Electron Energy Loss Spectroscopy (EELS).

Check out the :ref:`installation <install-label>` section for further information,
including how to start using this project.

.. note::

   This is an open-source community project: everyone is welcome to contribute.
   Please read our (see :ref:`contributing_label`) guidelines and get started!


Learning resources
==================

.. grid:: 2 3 3 3
  :gutter: 2

  .. grid-item-card::
    :link: user_guide/install
    :link-type: doc

    :octicon:`rocket;2em;sd-text-info` Getting Started
    ^^^

    New to HyperSpy or Python? The getting started guide provides an
    introduction on basic usage of HyperSpy and how to install it.

  .. grid-item-card::
    :link: user_guide/index
    :link-type: doc

    :octicon:`book;2em;sd-text-info` User Guide
    ^^^

    The user guide provides in-depth information on key concepts of HyperSpy
    and how to use it along with background information and explanations.

  .. grid-item-card::
    :link: reference/index
    :link-type: doc

    :octicon:`code-square;2em;sd-text-info` Reference
    ^^^

    Documentation of the metadata specification and of the Application Progamming Interface (API),
    which describe how HyperSpy functions work and which parameters can be used.

  .. grid-item-card::
    :link: auto_examples/index
    :link-type: doc

    :octicon:`zap;2em;sd-text-info` Example
    ^^^

    Short examples illustrating simple tasks.

  .. grid-item-card::
    :link: https://github.com/hyperspy/exspy-demos

    :octicon:`workflow;2em;sd-text-info` Tutorials
    ^^^

    Tutorials in form of Jupyter Notebooks to learn how to
    process multi-dimensional data using HyperSpy.

  .. grid-item-card::
    :link: contributing
    :link-type: doc

    :octicon:`people;2em;sd-text-info` Contributing
    ^^^

    HyperSpy is a community project maintained for and by its users.
    There are many ways you can help!

Citing exSpy
============

If exSpy has been significant to a project that leads to an academic
publication, please acknowledge that fact by citing it. The DOI in the
badge below is the `Concept DOI <https://help.zenodo.org/faq/#versioning>`_ of
HyperSpy. It can be used to cite the project without referring to a specific
version. If you are citing exSpy because you have used it to process data,
please use the DOI of the specific version that you have employed. You can
find it by clicking on the DOI badge below.

.. image:: https://zenodo.org/badge/doi/10.5281/zenodo.592838.svg
   :target: https://doi.org/10.5281/zenodo.592838

HyperSpy's citation in the scientific literature
------------------------------------------------

Given the increasing number of articles that cite HyperSpy we do not maintain a list of
articles citing HyperSpy. For an up to date list search for
HyperSpy in a scientific database e.g. `Google Scholar
<https://scholar.google.co.uk/scholar?q=hyperspy>`_.

.. Warning::
    Articles published before 2012 may mention the HyperSpy project under
    its old name, `EELSLab`.


License
=======

**exSpy** is free software: you can redistribute it and/or modify
it under the terms of the `GNU General Public License (GPL)
<https://www.gnu.org/licenses/#GPL>`_ as published by
the Free Software Foundation, either version 3 of the license, or
(at your option) any later version.

**exSpy** is distributed in the hope that it will be useful,
but **without any warranty**; without even the implied warranty of
**merchantability** or **fitness for a particular purpose**. See the
`GNU General Public License <https://www.gnu.org/licenses/#GPL>`_
for more details.
